@@ -1,7 +1,7 @@
-"""
+"""Raise the level of the constructors module.
 
 :author: Shay Hill
-created: 12/22/2019
+created: 12/22/2019.
 """
 from svg_ultralight.constructors.new_element import (
     deepcopy_element,
